@@ -149,30 +149,22 @@ NULL
 
 #' Get or Set the Default Calendar
 #'
-#' @param object A [`character`] string specifying the abbreviated label of
+#' @param x A [`character`] string specifying the abbreviated label of
 #'  the time scale (see [calendar()]) or an object from which to extract the
 #'  time scale.
-#' @param ... Currently not used.
+#' @param which A [`character`] string specifying the calendar to be set.
+#'  It must be one of "`default`" or "`current`". Note that "`current`" is
+#'  automatically set by [plot()] or [image()] and should not be changed
+#'  manually.
 #' @return
 #'  A [`TimeScale-class`] object.
 #' @example inst/examples/ex-calendar.R
 #' @author N. Frerebeau
 #' @docType methods
 #' @family calendar tools
-#' @aliases get_calendar-method
-setGeneric(
-  name = "get_calendar",
-  def = function(...) standardGeneric("get_calendar"),
-  valueClass = "TimeScale"
-)
-
+#' @name get_calendar
 #' @rdname get_calendar
-#' @aliases set_calendar-method
-setGeneric(
-  name = "set_calendar",
-  def = function(object) standardGeneric("set_calendar"),
-  valueClass = "TimeScale"
-)
+NULL
 
 #' Calendar Parameters
 #'
@@ -587,28 +579,6 @@ setGeneric(
   def = function(x, ...) standardGeneric("overlap")
 )
 
-#' Interval Graph
-#'
-#' @param object A [`TimeIntervals-class`] object.
-#' @param aggregate A [`logical`] scalar: should disjoint intervals referring to
-#'  the same event be aggregated?
-#' @param ... Currently not used.
-#' @details
-#'  An interval graph is the graph showing intersecting intervals on a line.
-#'  As time is linear and not circular, an interval graph contains no cycles
-#'  with more than three edges and no shortcuts.
-#' @return
-#'  An \pkg{igraph} graph object.
-#' @example inst/examples/ex-graph.R
-#' @author N. Frerebeau
-#' @docType methods
-#' @family chronological reasoning tools
-#' @aliases as_graph-method
-setGeneric(
-  name = "as_graph",
-  def = function(object, ...) standardGeneric("as_graph")
-)
-
 # Tools ========================================================================
 #' Terminal Times
 #'
@@ -698,6 +668,8 @@ setGeneric(
 #'  be given.
 #' @param calendar A [`TimeScale-class`] object specifying the target calendar
 #'  (see [calendar()]).
+#' @param groups A [`character`] vector specifying the group each interval
+#'  belongs to.
 #' @param sort A [`logical`] scalar: should the data be sorted in chronological
 #'  order?
 #' @param decreasing A [`logical`] scalar: should the sort order be decreasing?
